--- a/vregistry.py Tue Jul 07 12:24:40 2009 +0200
+++ b/vregistry.py Tue Jul 07 12:27:29 2009 +0200
@@ -1,10 +1,10 @@
"""
-* the vregistry handle various type of objects interacting
- together. The vregistry handle registration of dynamically loaded
- objects and provide a convenient api access to those objects
+* the vregistry handles various types of objects interacting
+ together. The vregistry handles registration of dynamically loaded
+ objects and provides a convenient api to access those objects
according to a context
-* to interact with the vregistry, object should inherit from the
+* to interact with the vregistry, objects should inherit from the
VObject abstract class
* the selection procedure has been generalized by delegating to a
@@ -188,9 +188,6 @@
# methods for explicit (un)registration ###################################
-# def clear(self, key):
-# regname, oid = key.split('.')
-# self[regname].pop(oid, None)
def register_all(self, objects, modname, butclasses=()):
for obj in objects:
try: